PyZillow 0.7
============

.. image:: https://img.shields.io/pypi/dm/pyzillow.svg
  :target: https://pypistats.org/packages/pyzillow
  :alt: PyPI - Downloads
.. image:: https://travis-ci.com/hanneshapke/pyzillow.svg?branch=master
  :target: https://travis-ci.com/hanneshapke/pyzillow
  :alt: Travis CI Build Status
.. image:: https://readthedocs.org/projects/pyzillow/badge/?version=latest
  :target: https://pyzillow.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status
.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
  :target: https://opensource.org/licenses/MIT
  :alt: License: MIT

PyZillow is a Python wrapper for `Zillow's API <http://www.zillow.com/howto/api/APIOverview.htm>`_. With PyZillow, you can use a physical address or a Zillow ID to access real estate data from the Zillow database.

Currently, PyZillow supports the **GetDeepSearchResults** and **GetUpdatedPropertyDetails** API endpoints.

Status
------

PyZillow is now being actively updated again. Please allow us some time
to work through existing pull requests and issues.

Documentation
-------------

The PyZillow documentation is available here: http://pyzillow.readthedocs.org/en/latest/

Maintainers
-----------

* Timo Cornelius Metzger <pyzillow@tcmetzger.net>
* Hannes Hapke <hannes@renooble.com>

Contributors
------------

* Alvaro Feito <alvaro@renooble.com>
* Bryce Boe <bbzbryce@gmail.com>
* Hannes Hapke <hannes@renooble.com>
* Miguel Paolino <miguel@renooble.com>
* Timo Cornelius Metzger <pyzillow@tcmetzger.net>

PyZillow was originally developed by Hannes Hapke and Miguel Paolino for `renooble.com <http://www.renooble.com>`_.
